==> firebase_analytics_web-0.4.0%2B13.tar.gz: CHANGELOG.md <==
## 0.4.0+13

 - Update a dependency to the latest release.

## 0.4.0+12

 - Update a dependency to the latest release.

## 0.4.0+11

 - Update a dependency to the latest release.

## 0.4.0+10

 - Update a dependency to the latest release.

## 0.4.0+9

 - Update a dependency to the latest release.

## 0.4.0+8

 - **FIX**: update all Dart SDK version constraints to Dart >= 2.16.0 (#8184). ([df4a5bab](https://github.com/FirebaseExtended/flutterfire/commit/df4a5bab3c029399b4f257a5dd658d302efe3908))

## 0.4.0+7

 - Update a dependency to the latest release.

## 0.4.0+6

 - Update a dependency to the latest release.

## 0.4.0+5

 - Update a dependency to the latest release.

## 0.4.0+4

 - Update a dependency to the latest release.

## 0.4.0+3

 - **FIX**: ensure `setDefaultEventParameters()` API throws stating not supported on web. (#7522). ([9a83f121](https://github.com/FirebaseExtended/flutterfire/commit/9a83f1219e33090bc8dbdd9bf26316e7fc6e7979))

## 0.4.0+2

 - Update a dependency to the latest release.

## 0.4.0+1

 - **FIX**: use `jsify()` with event parameters for `logEvent()` so they are sent (#7509).

## 0.4.0

 - Graduate package to a stable release. See pre-releases prior to this version for changelog entries.

## 0.4.0-dev.6

 - Update a dependency to the latest release.

## 0.4.0-dev.5

 - Update a dependency to the latest release.

## 0.4.0-dev.4

 - **FEAT**: automatically inject Firebase JS SDKs (#7359).

## 0.4.0-dev.3

 - **FEAT**: add macOS support (#7313).

## 0.4.0-dev.2

 - **FEAT**: support initializing default `FirebaseApp` instances from Dart (#6549).

## 0.4.0-dev.1

 - Update a dependency to the latest release.

## 0.4.0-dev.0

> Note: This release has breaking changes.

 - **STYLE**: enable additional lint rules (#6832).
 - **BREAKING** **REFACTOR**: update Firebase Analytics plugin to match latest Firebase APIs (#7032).
   - See `firebase_analytics` package changelog for more information.

## 0.3.0+1

 - **DOCS**: Add missing homepage/repository links (#6054).
 - **CHORE**: update Web plugins to use Firebase JS SDK version 8.4.1 (#4464).

## 0.3.0

 - Graduate package to a stable release. See pre-releases prior to this version for changelog entries.

## 0.3.0-dev.0

> Note: This release has breaking changes.

 - **BREAKING** **FEAT**: Migrate firebase_analytics to sound null safety (#5341).

## 0.2.0+1

 - **FIX**: upgrade `firebase` in firebase_analytics_web (#5276).
 - **CHORE**: enable missing lints on firebase_analytics (#5231).

## 0.2.0

 - This version is not null-safe but has been created to allow compatibility with other null-safe FlutterFire packages such as `firebase_core`.

## 0.1.1

- Add missing iOS files to be able to endorse this plugin as the web implementation of firebase_analytics.

## 0.1.0

- Initial implementation for firebase_analytics_web.

==> firebase_analytics_web-0.5.1%2B13.tar.gz: CHANGELOG.md <==
## 0.5.1+13

 - Update a dependency to the latest release.

## 0.5.1+12

 - Update a dependency to the latest release.

## 0.5.1+11

 - Update a dependency to the latest release.

## 0.5.1+10

 - Update a dependency to the latest release.

## 0.5.1+9

 - Update a dependency to the latest release.

## 0.5.1+8

 - Update a dependency to the latest release.

## 0.5.1+7

 - Update a dependency to the latest release.

## 0.5.1+6

 - Update a dependency to the latest release.

## 0.5.1+5

 - Update a dependency to the latest release.

## 0.5.1+4

 - Update a dependency to the latest release.

## 0.5.1+3

 - Update a dependency to the latest release.

## 0.5.1+2

 - Update a dependency to the latest release.

## 0.5.1+1

 - Update a dependency to the latest release.

## 0.5.1

- Update a dependency to the latest release.

## 0.5.0

> Note: This release has breaking changes.

 - **BREAKING** **FEAT**: Firebase iOS SDK version: `10.0.0` ([#9708](https://github.com/firebase/flutterfire/issues/9708)). ([9627c56a](https://github.com/firebase/flutterfire/commit/9627c56a37d657d0250b6f6b87d0fec1c31d4ba3))

## 0.4.2+7

 - Update a dependency to the latest release.

## 0.4.2+6

 - Update a dependency to the latest release.

## 0.4.2+5

 - Update a dependency to the latest release.

## 0.4.2+4

 - Update a dependency to the latest release.

## 0.4.2+3

 - **FIX**: `setCurrentScreen()` API is now obsolete, using `logEvent()` instead ([#9397](https://github.com/firebase/flutterfire/issues/9397)). ([490ef204](https://github.com/firebase/flutterfire/commit/490ef204b9873fca994f1a69ddf7962e6d735c4b))

## 0.4.2+2

 - Update a dependency to the latest release.

## 0.4.2+1

 - Update a dependency to the latest release.

## 0.4.2

 - **FEAT**: retrieves `appInstanceId` property on native platforms if available ([#8689](https://github.com/firebase/flutterfire/issues/8689)). ([7132d771](https://github.com/firebase/flutterfire/commit/7132d771ed5ada7a0433232b9f0d996ef0d61481))

## 0.4.1+1

 - **FIX**: allow `null` values for `setDefaultEventParameters()` which removes defaults. Permissible on android and iOS. ([#9135](https://github.com/firebase/flutterfire/issues/9135)). ([dff46a3f](https://github.com/firebase/flutterfire/commit/dff46a3f33d0b9881864f79be659b2770526677d))

## 0.4.1

 - **FEAT**: upgrade to support v9.8.1 Firebase JS SDK ([#8235](https://github.com/firebase/flutterfire/issues/8235)). ([4b417af5](https://github.com/firebase/flutterfire/commit/4b417af574bb8a32ca8e4b3ab2ff253a22be9903))

## 0.4.0+17

 - Update a dependency to the latest release.

## 0.4.0+16

 - Update a dependency to the latest release.

## 0.4.0+15

 - **REFACTOR**: use "firebase" instead of "FirebaseExtended" as organisation in all links for this repository (#8791). ([d90b8357](https://github.com/firebase/flutterfire/commit/d90b8357db01d65e753021358668f0b129713e6b))

## 0.4.0+14

 - Update a dependency to the latest release.

## 0.4.0+13

 - Update a dependency to the latest release.

## 0.4.0+12

 - Update a dependency to the latest release.

## 0.4.0+11

 - Update a dependency to the latest release.

## 0.4.0+10

 - Update a dependency to the latest release.

## 0.4.0+9

 - Update a dependency to the latest release.

## 0.4.0+8

 - **FIX**: update all Dart SDK version constraints to Dart >= 2.16.0 (#8184). ([df4a5bab](https://github.com/firebase/flutterfire/commit/df4a5bab3c029399b4f257a5dd658d302efe3908))

## 0.4.0+7

 - Update a dependency to the latest release.

## 0.4.0+6

 - Update a dependency to the latest release.

## 0.4.0+5

 - Update a dependency to the latest release.

## 0.4.0+4

 - Update a dependency to the latest release.

## 0.4.0+3

 - **FIX**: ensure `setDefaultEventParameters()` API throws stating not supported on web. (#7522). ([9a83f121](https://github.com/firebase/flutterfire/commit/9a83f1219e33090bc8dbdd9bf26316e7fc6e7979))

## 0.4.0+2

 - Update a dependency to the latest release.

## 0.4.0+1

 - **FIX**: use `jsify()` with event parameters for `logEvent()` so they are sent (#7509).

## 0.4.0

 - Graduate package to a stable release. See pre-releases prior to this version for changelog entries.

## 0.4.0-dev.6

 - Update a dependency to the latest release.

## 0.4.0-dev.5

 - Update a dependency to the latest release.

## 0.4.0-dev.4

 - **FEAT**: automatically inject Firebase JS SDKs (#7359).

## 0.4.0-dev.3

 - **FEAT**: add macOS support (#7313).

## 0.4.0-dev.2

 - **FEAT**: support initializing default `FirebaseApp` instances from Dart (#6549).

## 0.4.0-dev.1

 - Update a dependency to the latest release.

## 0.4.0-dev.0

> Note: This release has breaking changes.

 - **STYLE**: enable additional lint rules (#6832).
 - **BREAKING** **REFACTOR**: update Firebase Analytics plugin to match latest Firebase APIs (#7032).
   - See `firebase_analytics` package changelog for more information.

## 0.3.0+1

 - **DOCS**: Add missing homepage/repository links (#6054).
 - **CHORE**: update Web plugins to use Firebase JS SDK version 8.4.1 (#4464).

## 0.3.0

 - Graduate package to a stable release. See pre-releases prior to this version for changelog entries.

## 0.3.0-dev.0

> Note: This release has breaking changes.

 - **BREAKING** **FEAT**: Migrate firebase_analytics to sound null safety (#5341).

## 0.2.0+1

 - **FIX**: upgrade `firebase` in firebase_analytics_web (#5276).
 - **CHORE**: enable missing lints on firebase_analytics (#5231).

## 0.2.0

 - This version is not null-safe but has been created to allow compatibility with other null-safe FlutterFire packages such as `firebase_core`.

## 0.1.1

- Add missing iOS files to be able to endorse this plugin as the web implementation of firebase_analytics.

## 0.1.0

- Initial implementation for firebase_analytics_web.
